[![Build Status](https://travis-ci.org/bourbaki-py/application.svg?branch=master)](https://travis-ci.org/bourbaki-py/application)
[![Coverage Status](https://coveralls.io/repos/github/bourbaki-py/application/badge.svg?branch=master)](https://coveralls.io/github/bourbaki-py/application?branch=master)